function eliminarFila(idPeriodo, idCategoria, tipo){	
	var valido = true;
	
	if(idCategoria > 0 && (tipo == 0 || tipo == 1))
		verificarCateTitulos(idPeriodo, idCategoria, tipo, 1);												
	else if ( idCategoria > 0 && tipo == 2)
	{
		$("#tablaBono tr[id="+idCategoria+"]").remove();
		var categorias = [];			
		categorias.push({ "descCategoria": null, "idCategoria": idCategoria, "rangos": null });		
		categoriasEliminar.push({ "categorias": categorias, "idContratoPago": idPeriodo, "tipoPago": tipo });	
	}		
	else if ( idCategoria <= 0)
	{					
		if(tipo == 0)
		{
			$("div.contenedor > div.divtabla > table.tSuscriptores").each(function(){								
				$(this).find("tr[id="+idCategoria+"]").remove();														
			});
		}
		if(tipo == 1)
		{
			$("div.contenedor > div.divtabla > table.tFlat").each(function(){								
				$(this).find("tr[id="+idCategoria+"]").remove();														
			});
		}
		if(tipo == 2)
			$("#tablaBono tr[id="+idCategoria+"]").remove();
	}			
}

function eliminarFilaActual(idPeriodo, idCategoria, tipo){
		var categorias = [];	
		var categoria = { "descCategoria": null, "idCategoria": idCategoria, "rangos": null };
		categorias.push(categoria);
		var item      = { "categorias": categorias, "idContratoPago": idPeriodo, "tipoPago": tipo };
		categoriasEliminar.push(item);
					  	
		if(tipo == 0)
		{
			$("div.contenedor > div.divtabla > table.tSuscriptores").each(function(){								
				$(this).find("tr[id="+idCategoria+"]").remove();														
			});
		}
		if(tipo == 1)
		{
			$("div.contenedor > div.divtabla > table.tFlat").each(function(){								
				$(this).find("tr[id="+idCategoria+"]").remove();														
			});
		}		
}

function eliminarPeriodo(idPeriodo){		
	if(idPeriodo > 0)
		verificarCateTitulos(idPeriodo,null,null, 2);		
	else if(tipoSuscriptor == "s")
		$("#Contenedor"+idPeriodo).remove();
}
	
function eliminarPeriodoActual(idPeriodo){						
		var periodo;
		if(tipoSuscriptor == "s")
		{
			periodo = obtenerSuscriptor($("#Contenedor"+idPeriodo));
			$("#Contenedor"+idPeriodo).remove();
		}								
		else
		{			
			periodo = crearPeriodo(null, null, null, parseInt(idPeriodo));
						
			var idPer = parseInt($("table.bono").attr("id").substr(9,$("table.bono").attr("id").length)); 
			if( idPer == parseInt(idPeriodo) )
			{
				periodo.bonoSuscriptor = {"idContratoPago":idPeriodo, "nuevo":0, "anioInicio":"", "idTipoSuscriptor":"", "rangos":null};				
			}						   				
			eliminarColFlat(idPeriodo);
		}							
		periodosEliminar.push(periodo);				
}

function verificarCateTitulos(idPeriodo, idCategoria, tipoFee, tipo){		
	var mensaje = "";
	var id = 0;
	
	if(tipo == 1)
		id = idCategoria;					  
	if(tipo == 2)
		id = idPeriodo;
	  				
	$.post( contextPath + '/contrato/fees/verificarCategoriasTitulos.action', { request: id, operacion: tipo} )
	.done(function( response ) 
	{							
		if(response.msgExito != "")
		{									
			if(tipo == 1)
				mensaje = "La categor\u00EDa no puede ser eliminada ";							  
			if(tipo == 2)
				mensaje = "El periodo no puede ser eliminado ";			  
			if(tipo == 3)
			  mensaje = "El contrato no puede actualizarse ";
			
			$('#dialogTitulosCate').find('div.modal-body').text(mensaje + "porque tiene " + response.msgExito + " t\u00EDtulos asociados.");
			$('#dialogTitulosCate').modal("show");			
		}			       
		else
		{			
			if(tipo == 1)
				eliminarFilaActual(idPeriodo, idCategoria, tipoFee);							  
			if(tipo == 2)
				eliminarPeriodoActual(idPeriodo);						  
			if(tipo == 3)
			   $("#forma").submit();			
		}
	});		  		
}

function calculaValorInflacion(valor, inflacion){		
	if(validaNumero(valor) && valor != "")
	{
		valor = parseInt(valor);	
		if(inflacion != "")
		   valor = Math.round(((parseInt(inflacion) * valor) / 100)) + valor;	
	}
	else
		valor = "";		
	return valor;
}

function crearFilaVacia(clase, numDatos, atributos, colspan){
    var fila  = $("<tr/>").addClass(clase);
	 
	 for(var i=0; i < atributos.length; i++)		 
	     fila.attr(atributos[i][0],atributos[i][1]);			 		 
	
	for(var i=0; i < numDatos; i++)		 
	     fila.append(createTdThTabla(colspan, "", true, null, 1));
	 
	return fila;
}

function addYear(fecha){
	var date = new Date(fecha);
	var newdate = new Date(date);

	newdate.setDate(newdate.getDate() + 364);
	    
	var dd = newdate.getDate();
	var mm = newdate.getMonth() + 1;
	var y = newdate.getFullYear();

	var someFormattedDate = mm + '/' + dd + '/' + y;
	return someFormattedDate;
}

function formatCurrency(unformatedCurrency, n, x) {
	var re = '\\d(?=(\\d{' + (x || 3) + '})+' + (n > 0 ? '\\.' : '$') + ')';
	return unformatedCurrency.toFixed(Math.max(0, ~~n)).replace(new RegExp(re, 'g'), '$&,');
};

function unformatCurrency(formatedCurrency) {
	return String(formatedCurrency).replace(/ /g, "").replace(/,/g, "").replace("$", "");
};

